@@ -1,21 +1,15 @@
-# coding:utf-8
-u"""
-Внешнее API для подсистемы m3_users
-===================================
+# coding: utf-8
 
-.. Created on 09.12.2010
+u"""Внешнее API для подсистемы m3_users."""
+from six import string_types
 
-.. @author: akvarats
-"""
+from django.contrib.auth import get_user_model
 
-from django.contrib.auth import models as auth_models
-from django.db import transaction
+from m3_django_compat import atomic
 
-from m3_legacy import get_object_by_id
-
-from helpers import get_assigned_metaroles_query
-from metaroles import get_metarole
-import models
+from .helpers import get_assigned_metaroles_query
+from .metaroles import get_metarole
+from . import models
 
 
 SUPER_ADMIN_METAROLE = 'super-admin'
@@ -38,9 +32,8 @@ def get_user_metaroles(user):
 
 
 def user_has_metarole(user, metarole):
-    u"""
-    Возвращает True в случае, если пользователю назначена метароль, иначе False.
-    
+    u"""Возвращает True, если пользователю назначена метароль, иначе False.
+
     :param user: пользователь, для которого проверяется наличие метароли
     :type user: :py:class:`django.contrib.auth.models.User`
     :param str metarole: метароль
@@ -58,10 +51,12 @@ def get_user_roles(user):
     :param user: пользователь системы
     :type user: :py:class:`django.contrib.auth.models.User`
     """
-    return models.UserRole.objects.filter(assigned_users__user=user).order_by('name')
+    return models.UserRole.objects.filter(
+        assigned_users__user=user
+    ).order_by('name')
 
 
-@transaction.commit_on_success
+@atomic
 def remove_user_role(user, role):
     u"""
     Снимает роль у пользователя.
@@ -73,24 +68,29 @@ def remove_user_role(user, role):
 
     .. note::
 
-        если снимаем роль у суперпользователя, и него не осталось ролей, наследовынных от метароли
-        Супер-Администратора, то сниматся с него флаг суперпользователя
+        если снимаем роль у суперпользователя, и него не осталось ролей,
+        наследованных от метароли Супер-Администратора, то сниматся с него
+        флаг суперпользователя
     """
     models.AssignedRole.objects.filter(user=user, role=role).delete()
 
     if isinstance(user, int):
-        user = auth_models.User.objects.get(id=user)
+        user = get_user_model().objects.get(id=user)
 
-    # снимаем флаг супер-пользователя, если он стоял, и у пользователя не осталось
-    # ролей, наследовынных от метароли Супер-Администратора
-    if user.is_superuser \
-            and not models.UserRole.objects.filter(metarole=SUPER_ADMIN_METAROLE,
-                                                   assigned_users__user=user).exists():
+    # снимаем флаг супер-пользователя, если он стоял, и у пользователя не
+    # осталось ролей, наследовынных от метароли Супер-Администратора
+    if (
+        user.is_superuser and not
+        models.UserRole.objects.filter(
+            metarole=SUPER_ADMIN_METAROLE,
+            assigned_users__user=user
+        ).exists()
+    ):
         user.is_superuser = False
         user.save()
 
 
-@transaction.commit_on_success
+@atomic
 def set_user_role(user, role):
     u"""
     Устанавливает роль для пользователя
@@ -102,16 +102,18 @@ def set_user_role(user, role):
 
     .. note::
 
-        если роль суперпользователя, то пользователю ставится флаг суперпользователя
+        если роль суперпользователя, то пользователю ставится флаг
+        суперпользователя
     """
-    # TODO: что этим хотел сказать автор? можно как-то красиво это сделать можно? например exists()
+    # TODO: что этим хотел сказать автор? можно как-то красиво это сделать?
+    # TODO: например exists()
     if len(models.AssignedRole.objects.filter(user=user, role=role)[0:1]) == 0:
 
         if isinstance(role, int):
             role = models.UserRole.objects.get(id=role)
 
         if isinstance(user, int):
-            user = auth_models.User.objects.get(id=user)
+            user = get_user_model().objects.get(id=user)
 
         assigned_role = models.AssignedRole()
         assigned_role.user = user
@@ -123,7 +125,7 @@ def set_user_role(user, role):
             user.save()
 
 
-@transaction.commit_on_success
+@atomic
 def clear_user_roles(user):
     u"""
     Убирает все роли у пользователя
@@ -133,12 +135,13 @@ def clear_user_roles(user):
 
     .. note::
 
-        если пользователь суперпользователь, то снимается флаг суперпользователя
+        если пользователь суперпользователь, то снимается флаг
+        суперпользователя
     """
     models.AssignedRole.objects.filter(user=user).delete()
 
     if isinstance(user, int):
-        user = auth_models.User.objects.get(id=user)
+        user = get_user_model().objects.get(id=user)
 
     if user.is_superuser:
         user.is_superuser = False
@@ -146,13 +149,24 @@ def clear_user_roles(user):
 
 
 def get_user_by_id(user_id):
-    u"""
-    Возвращает экземпляр пользователя :py:class:`django.contrib.auth.models.User` по указанному идентификатору.
+    u"""Возвращает экземпляр пользователя AUTH_USER_MODEL по идентификатору.
 
     :param int user_id: искомый пользователь
 
     .. note::
 
-        если вдруг в user_id передан реальный пользователь, то он и возвращается.
+        если вдруг в user_id передан реальный пользователь, то он и
+        возвращается.
     """
-    return get_object_by_id(auth_models.User, user_id)
\ No newline at end of file
+    result = None
+    model = get_user_model()
+
+    if isinstance(user_id, (int, string_types)):
+        try:
+            result = model.objects.get(pk=user_id)
+        except model.DoesNotExist:
+            result = None
+    elif isinstance(user_id, model):
+        result = user_id
+
+    return result
