@@ -3,8 +3,10 @@ u"""
 Права ролей
 ===========
 """
-from django.contrib.auth.models import User
 from django.contrib.auth import get_backends
+from django.contrib.auth import get_user_model
+
+from m3_django_compat import is_authenticated
 
 # TODO: можно обойтись from models import RolePermission
 from m3_users.models import RolePermission
@@ -53,7 +55,7 @@ class ActionsBackend(object):
         :param user_obj: пользователь
         :type user_obj: :py:class:`django.contrib.auth.models.User`
         """
-        if user_obj.is_anonymous():
+        if not is_authenticated(user_obj):
             return set()
         return self.get_group_permissions(user_obj)
 
@@ -88,6 +90,7 @@ class ActionsBackend(object):
 
         :param int user_id: идентификатор пользователя
         """
+        User = get_user_model()
         try:
             return User.objects.get(pk=user_id)
         except User.DoesNotExist:
