@@ -60,7 +60,14 @@ function deletePermission() {
                 }
             }
         });
-    };
+    } else {
+        Ext.Msg.show({
+            title: 'Удаление',
+            msg: 'Элемент не выбран!',
+            buttons: Ext.Msg.OK,
+            icon: Ext.Msg.INFO
+        });
+    }
 }
 
 {% block content %}
